@@ -1,4 +1,4 @@
-/* $Id: synce_socket.c 2574 2006-09-14 14:38:41Z twogood $ */
+/* $Id: synce_socket.c 2967 2007-06-02 12:11:23Z ralimi $ */
 #include "synce_socket.h"
 #include "synce_log.h"
 #include <stdlib.h>
@@ -69,6 +69,14 @@ int synce_socket_get_descriptor(SynceSocket* socket)
   return socket->fd;
 }
 
+void synce_socket_take_descriptor(SynceSocket* socket, int fd)
+{
+  if (socket->fd != SYNCE_SOCKET_INVALID_DESCRIPTOR)
+    close(socket->fd);
+
+  socket->fd = fd;
+}
+
 static bool synce_socket_create(SynceSocket* syncesock)
 {
 	bool success = false;
@@ -287,13 +295,46 @@ bool synce_socket_close(SynceSocket* socket)
 
 bool synce_socket_write(SynceSocket* socket, const void* data, unsigned size)
 {
+	int bytes_left = size;
+
 	if ( SYNCE_SOCKET_INVALID_DESCRIPTOR == socket->fd )
 	{
 		synce_socket_error("Invalid file descriptor");
 		return false;
 	}
 
-	return write(socket->fd, data, size) == (int)size;
+	while (bytes_left > 0)
+	{
+		int result = write(socket->fd, data, bytes_left);
+
+		if (result == 0)
+		{
+			/* Should only happen if 'bytes_left == 0'.  That is,
+			 * no more data left to be written. */
+			break;
+		}
+		else if (result < 0 && (errno == EINTR || errno == EAGAIN))
+		{
+			/* There was either an interrupt or some other reason
+			 * we should try again. */
+			continue;
+		}
+		else if (result < 0)
+		{
+			/* Something else went wrong. */
+			synce_socket_error("write failed, error: %i \"%s\"", errno, strerror(errno));
+
+			/* Close socket on unrecoverable errors */
+			if (ECONNRESET == errno)  /* Connection reset by peer */
+				synce_socket_close(socket);
+			break;
+		}
+
+		bytes_left -= result;
+		data = (char*)data + result;
+	}
+
+	return 0 == bytes_left;
 }
 
 bool synce_socket_read(SynceSocket* socket, void* data, unsigned size)
@@ -312,13 +353,25 @@ bool synce_socket_read(SynceSocket* socket, void* data, unsigned size)
 
 		/* synce_socket_trace("read returned %i, needed %i bytes", result, bytes_needed); */
 
-		if (result <= 0)
+		if (result == 0)
 		{
+			/* EOF */
+			break;
+		}
+		else if (result < 0 && (errno == EINTR || errno == EAGAIN))
+		{
+			/* There was either an interrupt or some other reason
+			 * we should try again. */
+			continue;
+		}
+		else if (result < 0)
+		{
+			/* Something else went wrong. */
 			synce_socket_error("read failed, error: %i \"%s\"", errno, strerror(errno));
 
-      /* Close socket on unrecoverable errors */
-      if (ECONNRESET == errno)  /* Connection reset by peer */
-        synce_socket_close(socket);
+			/* Close socket on unrecoverable errors */
+			if (ECONNRESET == errno)  /* Connection reset by peer */
+				synce_socket_close(socket);
 			break;
 		}
 
