@@ -1,4 +1,4 @@
-/* $Id: synce_types.h 2447 2006-05-31 23:33:58Z oleavr $ */
+/* $Id: synce_types.h 3284 2008-02-18 15:48:43Z mark_ellis $ */
 #ifndef __synce_types_h__
 #define __synce_types_h__
 
@@ -34,6 +34,7 @@ typedef uint32_t  HWND;
 typedef uint32_t  BOOL;
 
 typedef int64_t LONGLONG;
+typedef uint64_t  ULARGE_INTEGER;
 
 
 /* XXX: sizeof(double) must be 8 */
@@ -51,6 +52,9 @@ typedef WCHAR*  LPWSTR;
 typedef HKEY*   PHKEY;
 typedef DWORD*  LPDWORD;
 typedef LONG*   PLONG;
+typedef ULARGE_INTEGER*         PULARGE_INTEGER ;
+typedef ULARGE_INTEGER*         LPULARGE_INTEGER;
+
 
 
 /*
@@ -60,6 +64,7 @@ typedef LONG*   PLONG;
 typedef const void*   LPCVOID;
 typedef const char*   LPCSTR;
 typedef const WCHAR*  LPCWSTR;
+typedef const char*   LPCTSTR ;
 
 
 /*
@@ -135,14 +140,20 @@ typedef int32_t  HRESULT;
 #define ERROR_SUCCESS                  0
 #define ERROR_FILE_NOT_FOUND           2
 #define ERROR_PATH_NOT_FOUND           3
+#define ERROR_TOO_MANY_OPEN_FILES      4
 #define ERROR_ACCESS_DENIED            5
+#define ERROR_INVALID_HANDLE           6
 #define ERROR_NOT_ENOUGH_MEMORY        8
+#define ERROR_NOT_SAME_DEVICE         17
+#define ERROR_NO_MORE_FILES           18
 #define ERROR_SEEK                    25
+#define ERROR_GEN_FAILURE             31
 #define ERROR_SHARING_VIOLATION       32
 #define ERROR_NOT_SUPPORTED           50
 #define ERROR_DUP_NAME                52
 #define ERROR_FILE_EXISTS             80
 #define ERROR_INVALID_PARAMETER       87
+#define ERROR_DISK_FULL              112
 #define ERROR_INSUFFICIENT_BUFFER    122
 #define ERROR_INVALID_NAME           123
 #define ERROR_DIR_NOT_EMPTY          145
@@ -155,7 +166,7 @@ typedef int32_t  HRESULT;
  * Other macros
  */
 
-#define MAX_PATH  256
+#define MAX_PATH  260
 
 #ifndef FALSE
 #define FALSE false
